@@ -1,4 +1,5 @@
-from .project_definitions import SUPPORTED_RELATIONAL_DATABASES
+from .project_definitions import SUPPORTED_NOSQL_DATABASES
+from .project_definitions import SUPPORTED_SQL_DATABASES
 from .project_logging import LOGGING_LEVELS
 from .project_logging import LOGO
 from .project_logging import LOGO_COLOR
