@@ -5,10 +5,14 @@ from collections.abc import AsyncGenerator
 from typing import Type, Union
 
 from illuminate.adapter import Adapter
+from illuminate.observation import FileObservation
 from illuminate.observation import HTTPObservation
+from illuminate.observation import SQLObservation
+from illuminate.observation import SplashObservation
 from illuminate.observer import Finding
 
-from exporters.example import ExporterExample
+from exporters.example import ExporterInfluxDBExample
+from exporters.example import ExporterSQLExample
 from findings.example import FindingExample
 from models.example import ModelExample
 
@@ -43,9 +47,33 @@ class AdapterExample(Adapter):
 
     async def adapt(
         self, finding: FindingExample, *args, **kwargs
-    ) -> AsyncGenerator[Union[ExporterExample, HTTPObservation], None]:
-        yield ExporterExample(
-            models=[ModelExample(title=finding.title, url=finding.url)]
+    ) -> AsyncGenerator[
+        Union[
+            ExporterInfluxDBExample,
+            ExporterSQLExample,
+            FileObservation,
+            HTTPObservation,
+            SQLObservation,
+            SplashObservation,
+        ],
+        None,
+    ]:
+        yield ExporterSQLExample(
+            models=[
+                ModelExample(
+                    load_time=finding.load_time,
+                    title=finding.title,
+                    url=finding.url
+                )
+            ]
+        )
+
+        yield ExporterInfluxDBExample(
+            points={{
+                "measurement": "{name}",
+                "tags": {{"url": finding.url, "title": finding.title}},
+                "fields": {{"load_time": finding.load_time}},
+            }}
         )
 
 """
@@ -57,7 +85,7 @@ from alembic import context
 from sqlalchemy import engine_from_config
 from sqlalchemy import pool
 
-from models.example import Base
+from models import Base
 from settings import MODELS
 
 for model in MODELS:
@@ -133,6 +161,35 @@ def downgrade():
 _DOCKER_COMPOSE = """
 version: '3.8'
 services:
+  grafana:
+   image: grafana/grafana
+   container_name: grafana
+   restart: always
+   depends_on:
+     - influxdb
+   environment:
+     - GF_SECURITY_ADMIN_USER=illuminate
+     - GF_SECURITY_ADMIN_PASSWORD=$ILLUMINATE_GRAFANA_PASSWORD
+     - GF_INSTALL_PLUGINS=
+   links:
+     - influxdb
+   ports:
+     - '3000:3000'
+   volumes:
+     - grafana:/var/lib/grafana
+  influxdb:
+    image: influxdb:1.8
+    container_name: influxdb
+    restart: always
+    environment:
+      - INFLUXDB_ADMIN_USER=illuminate
+      - INFLUXDB_ADMIN_PASSWORD=$ILLUMINATE_MEASUREMENTS_DB_PASSWORD
+      - INFLUXDB_DB={name}
+      - INFLUXDB_HTTP_AUTH_ENABLED=true
+    ports:
+      - '8086:8086'
+    volumes:
+      - influxdb:/var/lib/influxdb
   pg:
     container_name: pg
     image: postgres:latest
@@ -161,6 +218,10 @@ services:
     ports:
       - "8050:8050"
 volumes:
+  grafana:
+    driver: local
+  influxdb:
+    driver: local
   postgres:
     driver: local
 
@@ -172,14 +233,37 @@ _EMPTY = """
 _EXPORTER_EXAMPLE = """
 from __future__ import annotations
 
-from typing import Union
+from typing import Iterable, Union
 
+from illuminate.exporter import InfluxDBExporter
 from illuminate.exporter import SQLExporter
+from pandas import DataFrame
 
 from models.example import ModelExample
 
 
-class ExporterExample(SQLExporter):
+class ExporterInfluxDBExample(InfluxDBExporter):
+    \"\"\"
+    InfluxDBExporter class will write points to database using session. Points
+    are passed at initialization, while database session is found by name
+    attribute in the pool of existing sessions. Name must co-respond to DB
+    section in {name}/settings.py. For more information how to initialize
+    InfluxDBExporter class, check {name}/adapters/example.py
+    \"\"\"
+
+    name: str = "measurements"
+
+    def __init__(
+        self,
+        points: Union[
+            Union[DataFrame, dict, str, bytes],
+            Iterable[Union[DataFrame, dict, str, bytes]],
+        ],
+    ):
+        super().__init__(points)
+
+
+class ExporterSQLExample(SQLExporter):
     \"\"\"
     SQLExporter class will commit models to database using session. Models are
     passed at initialization, while database session is found by name attribute
@@ -201,10 +285,12 @@ _FIXTURE_EXAMPLE = """
     "name": "{name}",
     "data": [
         {{
+            "load_time": "1.0",
             "url": "https://webscraper.io/",
             "title": "Web Scraper - The #1 web scraping extension"
         }},
         {{
+            "load_time": "1.0",
             "url": "https://webscraper.io/tutorials",
             "title": "Web Scraper Tutorials"
         }}
@@ -221,7 +307,7 @@ Base = declarative_base()
 """
 
 _MODEL_EXAMPLE = """
-from sqlalchemy import Column, Integer, String
+from sqlalchemy import Column, Float, Integer, String
 
 from models import Base
 
@@ -234,12 +320,16 @@ class ModelExample(Base):
 
     __tablename__ = "{name}"
     id: int = Column(Integer, primary_key=True)
+    load_time: float = Column(Float)
     title: str = Column(String)
     url: str = Column(String)
 
     def __repr__(self):
         \"\"\"ModelExample's __repr__ method.\"\"\"
-        return f'ModelExample(title="{{self.title}}",url="{{self.url}}")'
+        return (
+            f'ModelExample(load_time={{self.load_time}},'
+            f'title="{{self.title}}",url="{{self.url}}")'
+        )
 
 """
 
@@ -286,7 +376,14 @@ DB = {{
         "port": "5432",
         "user": "illuminate",
         "type": "postgresql",
-    }}
+    }},
+    "measurements": {{
+        "host": "localhost",
+        "pass": os.environ.get("ILLUMINATE_MEASUREMENTS_DB_PASSWORD"),
+        "port": "8086",
+        "user": "illuminate",
+        "type": "influxdb",
+    }},
 }}
 
 MODELS = [
@@ -338,6 +435,7 @@ class FindingExample(Finding):
     Check {name}/adapters/example.py to learn more about subscription.
     \"\"\"
 
+    load_time: float = field()
     title: str = field()
     url: str = field()
 
@@ -357,7 +455,8 @@ from illuminate.observation import HTTPObservation
 from illuminate.observer import Observer
 from tornado.httpclient import HTTPResponse
 
-from exporters.example import ExporterExample
+from exporters.example import ExporterInfluxDBExample
+from exporters.example import ExporterSQLExample
 from findings.example import FindingExample
 
 
@@ -425,7 +524,13 @@ class ObserverExample(Observer):
     async def observe(
         self, response: HTTPResponse, *args, **kwargs
     ) -> AsyncGenerator[
-        Union[ExporterExample, FindingExample, HTTPObservation], None
+        Union[
+            ExporterInfluxDBExample,
+            ExporterSQLExample,
+            FindingExample,
+            HTTPObservation,
+        ],
+        None,
     ]:
         \"\"\"
         ETL flow is regulated by a yielded object type of Observation's
@@ -462,7 +567,11 @@ class ObserverExample(Observer):
                 allowed=self.ALLOWED,
                 callback=self.observe,
             )
-        yield FindingExample(soup.title.text, response.effective_url)
+        yield FindingExample(
+            response.request_time,
+            soup.title.text,
+            response.effective_url
+        )
 
 """
 
