@@ -5,10 +5,10 @@ import inspect
 import json
 import os
 import traceback
-from glob import glob
 from types import ModuleType
 from typing import Type, Union
 
+from aioinflux import InfluxDBClient  # type: ignore
 from alembic import command
 from alembic.config import Config
 from alembic.operations import Operations
@@ -22,8 +22,10 @@ from illuminate.decorators import adapt
 from illuminate.decorators import show_info
 from illuminate.decorators import show_logo
 from illuminate.decorators import show_observer_catalogue
+from illuminate.exceptions import BasicExporterException
 from illuminate.exceptions import BasicManagerException
 from illuminate.exporter import Exporter
+from illuminate.exporter import InfluxDBExporter
 from illuminate.exporter import SQLExporter
 from illuminate.interface import IManager
 from illuminate.meta.type import Result
@@ -51,7 +53,7 @@ class Manager(IManager):
         name: str,
         observers: list[Type[Observer]],
         path: str,
-        sessions: dict[str, Type[AsyncSession]],
+        sessions: dict[str, Union[Type[AsyncSession], InfluxDBClient]],
         settings: ModuleType,
         *args,
         **kwargs,
@@ -114,12 +116,7 @@ class Manager(IManager):
         """
 
         table_data = {}
-        files = (
-            fixtures if fixtures else glob("fixtures/*.json", recursive=True)
-        )
-        for file in files:
-            logger.info(f"Database fixtures file discovered {file}")
-        for _file in files:
+        for _file in fixtures:
             with open(_file, "r") as file:  # type: ignore
                 content = json.load(file)  # type: ignore
                 for table in content:
@@ -309,7 +306,7 @@ class Manager(IManager):
         :param item: FileObservation object
         :return: None
         """
-        async with item.observe() as result:
+        async with item.observe(xcom=item.xcom) as result:
             await self.__observation_resolve(result, item.url)
 
     async def __observe_http(self, item: HTTPObservation) -> None:
@@ -324,7 +321,7 @@ class Manager(IManager):
             **self.settings.OBSERVATION_CONFIGURATION["http"],
             **item.configuration,
         }
-        result = await item.observe()
+        result = await item.observe(xcom=item.xcom)
         await self.__observation_resolve(result, item.url)
 
     async def __observe_sql(self, item: SQLObservation) -> None:
@@ -335,7 +332,7 @@ class Manager(IManager):
         :param item: SQLObservation object
         :return: None
         """
-        result = await item.observe(self.sessions[item.url])
+        result = await item.observe(self.sessions[item.url], xcom=item.xcom)
         await self.__observation_resolve(result, f"{item.url}:{item.query}")
 
     async def __observe_splash(self, item: SplashObservation) -> None:
@@ -351,7 +348,7 @@ class Manager(IManager):
             **item.configuration,
         }
         result = await item.observe(
-            self.settings.OBSERVATION_CONFIGURATION["http"]
+            self.settings.OBSERVATION_CONFIGURATION["http"], xcom=item.xcom
         )
         await self.__observation_resolve(result, item.url)
 
@@ -443,33 +440,37 @@ class Manager(IManager):
         async for item in self.__export_queue:
             if not item:
                 return
-            await self.__exportation(item)
+            await self.__export_to(item)
             logger.debug(f"Coroutine exported {item}")
             del item
             self.__export_queue.task_done()
 
-    async def __exportation(self, item: Exporter) -> None:
+    async def __export_to(self, item: Exporter) -> None:
         """
         Passes Exporter object to proper method based on its class.
 
         :param item: Exporter object
         :return: None
         """
-        if isinstance(item, SQLExporter):
-            await self.__exportation_sql(item)
+        if isinstance(item, (InfluxDBExporter, SQLExporter)):
+            await self.__export_to_database(item)
 
-    async def __exportation_sql(self, item: SQLExporter) -> None:
+    async def __export_to_database(
+        self, item: Union[InfluxDBExporter, SQLExporter]
+    ) -> None:
         """
         Acquires database session based on Exporter's attributes and pass it to
-        SQLExporter's export method.
+        Exporter's export method.
 
-        :param item: SQLExporter object
+        :param item: InfluxDBExporter or SQLExporter object
         :return: None
         """
         try:
             session = self.sessions[item.name]
             await item.export(session)
             self.__exported.add(item)
+        except BasicExporterException:
+            pass
         except KeyError:
             logger.critical(f"Database {item.name} of is not found in context")
 
@@ -505,3 +506,7 @@ class Manager(IManager):
         await observers
         await adapters
         await exporters
+
+        for session in self.sessions:
+            if isinstance(self.sessions[session], InfluxDBClient):
+                await self.sessions[session].close()  # type: ignore
